@@ -1,10 +1,9 @@
 from .utils import getEndpointUrl,get_async_response
 from abstract_apis import getRequest,requests,asyncPostRpcRequest,asyncPostRequest,asyncGetRequest,get_headers
+from abstract_utilities import make_list
 import json
 async def asyncMakeLimitedDbCall(method=None, params=[]):
-    response = getRequest(url=getEndpointUrl("dbSearch"), data={"method":method, "params":params},headers=get_headers())
-    print(type(response))
-    print(response)
+    response = getRequest(url=getEndpointUrl("dbSearch"), data={"method":method, "params":make_list(params)[0]},headers=get_headers())
     if response != None:
       print(f'search of {method}  successful')
       return response
