@@ -1,5 +1,5 @@
 import asyncio
-from abstract_apis import get_url,make_endpoint
+from abstract_apis import get_url,make_endpoint,get_headers
 def getSolcatcherUrl():
   return 'https://solcatcher.io'
 def getEndpointUrl(endpoint=None,url=None):
@@ -16,9 +16,16 @@ def ifListGetSection(listObj,section=0):
         if len(listObj)>section:
             return listObj[section]
     return listObj
-def get_async_response(func, *args, **kwargs):
-    if asyncio.get_event_loop().is_running():
-        # If already inside an event loop, use ensure_future or create_task
-        return asyncio.ensure_future(func(*args, **kwargs))
+def get_async_response(async_function, *args, **kwargs):
+    try:
+        loop = asyncio.get_event_loop()
+    except RuntimeError:
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+
+    if not loop.is_running():
+        # Only run the loop if it's not already running
+        return loop.run_until_complete(async_function(*args, **kwargs))
     else:
-        return asyncio.run(func(*args, **kwargs))
+        # If the loop is already running, directly run the coroutine
+        return asyncio.ensure_future(async_function(*args, **kwargs))
